@@ -100,13 +100,13 @@ struct totemudpu_instance {
 
 	void *context;
 
-	void (*totemudpu_deliver_fn) (
+	int (*totemudpu_deliver_fn) (
 		void *context,
 		const void *msg,
 		unsigned int msg_len,
 		const struct sockaddr_storage *system_from);
 
-	void (*totemudpu_iface_change_fn) (
+	int (*totemudpu_iface_change_fn) (
 		void *context,
 		const struct totem_ip_address *iface_address,
 		unsigned int ring_no);
@@ -540,6 +540,7 @@ static int net_deliver_fn (
 	}
 
 	if (instance->totem_config->block_unlisted_ips &&
+	    instance->netif_bind_state == BIND_STATE_REGULAR &&
 	    find_member_by_sockaddr(instance, (const struct sockaddr *)&system_from) == NULL) {
 		log_printf(instance->totemudpu_log_level_debug, "Packet rejected from %s",
 		    totemip_sa_print((const struct sockaddr *)&system_from));
@@ -956,13 +957,13 @@ int totemudpu_initialize (
 	totemsrp_stats_t *stats,
 	void *context,
 
-	void (*deliver_fn) (
+	int (*deliver_fn) (
 		void *context,
 		const void *msg,
 		unsigned int msg_len,
 		const struct sockaddr_storage *system_from),
 
-	void (*iface_change_fn) (
+        int (*iface_change_fn) (
 		void *context,
 		const struct totem_ip_address *iface_address,
 		unsigned int ring_no),
